//
//	MiscMailApp.m -- an API to NeXT's Mail.app
//		Modified by Don Yacktman (c) 1994 by Don Yacktman.
//				Version 1.0.  All rights reserved.
//
//		This notice may not be removed from this source code.
//
//	This object is included in the MiscKit by permission from the author
//	and its use is governed by the MiscKit license, found in the file
//	"LICENSE.rtf" in the MiscKit distribution.  Please refer to that file
//	for a list of all applicable permissions and restrictions.
//

#import <misckit/MiscMailApp.h>
#import <misckit/MiscDictionary.h>
#import <appkit/appkit.h>

@interface MiscMailApp(private)
- _MiscRealInitForHostNamed:host;
@end

@implementation MiscMailApp

+ localMailer
{
	return [self mailerForHostNamed:nil];
}

+ mailerForHostNamed:aHost
{
	static id localMailer = nil;
	static id dictionary = nil;
	id theMailer = nil;

	if (aHost && strlen([aHost stringValue])) {
		if (!dictionary) {
			dictionary = [[MiscDictionary alloc] init];
		}
		theMailer = [dictionary valueForKey:aHost];
		if (!theMailer) {
			theMailer = [[super alloc] _MiscRealInitForHostNamed:aHost];
			if (theMailer) [dictionary insertKey:aHost value:theMailer];
		}
	} else { // go local if no name given
		if (!localMailer) {
			localMailer = [[super alloc] _MiscRealInitForHostNamed:nil];
		}
		theMailer = localMailer;
	}
	return theMailer;
}

- init
{
	return [self error:"You cannot use -init on MiscMailApp.\n"];
}

+ alloc
{
	return [self error:"You cannot use +alloc on MiscMailApp.\n"];
}

- _MiscRealInitForHostNamed:host
{
	port_t mailPort;

	if (_initted) return self;
	if (![super init]) return nil;
	if (host && [host length]) {
		hostName = [MiscString newWithString:[host stringValue]];
		// check to be sure that Mail.app is up and running first
		mailPort = NXPortFromName("Mail", [hostName stringValue]);
		mailPort = NXPortFromName("MailSendDemo", [hostName stringValue]);
	} else {
		hostName = [MiscString newWithString:"localhost"];
		// check to be sure that Mail.app is up and running first
		mailPort = NXPortFromName("Mail", NULL);
		mailPort = NXPortFromName("MailSendDemo", NULL);
	}
	if (!mailPort) { // couldn't connect, so we bail out.
		[self free];
		return nil;
	}
	theSpeaker = [MiscMailSpeaker new];
	[theSpeaker setSendPort:mailPort];
	currentWindow = 0; // no current window
	noclutter = NO;
	_initted = YES; // make sure the init method is not re-entered!
	return self;
}

- free
{
	[theSpeaker free];
	[hostName free];
	return self;
}

- hostname { return hostName; }
- (BOOL)noclutter { return noclutter; }
- setNoclutter:(BOOL)flag { noclutter = flag; return self; }

- sendMailTo:to subject:subject body:body
{
	return [self sendMailTo:to subject:subject body:body cc:nil andDeliver:NO];
}

- sendMailTo:to subject:subject body:body cc:cc andDeliver:(BOOL)flag
{
	[self openWindow];
	[self setTo:to];
	[self setSubject:subject];
	[self setBody:body];
	[self setCc:cc];
	if (flag) [self deliver];
	return self;
}

- openWindow
{
	if (noclutter && currentWindow) [self deliver];
	[theSpeaker openSend:&currentWindow];
	return self;
}

- deliver
{
	[theSpeaker deliver:currentWindow];
	currentWindow = 0; // there is no longer a current window
	return self;
}


#define MESSAGE(x) 	if (sender) if (strlen([sender stringValue])) \
		[theSpeaker x:[sender stringValue] inWindow:currentWindow]; \
	return self

- setSubject:sender
{
	MESSAGE(setSubject);
}

- setBody:sender
{
	MESSAGE(setBody);
}

- setTo:sender
{
	MESSAGE(setTo);
}

- setCc:sender
{
	MESSAGE(setCc);
}

// to allow target/action for everything...
- openWindow:sender { return [self openWindow]; }
- deliver:sender { return [self deliver]; }

@end
